:orphan:

`plasmapy.dispersion.analytical.stix_`
======================================

.. currentmodule:: plasmapy.dispersion.analytical.stix_

.. automodapi:: plasmapy.dispersion.analytical.stix_

Example Notebooks
-----------------

.. nbgallery::

    /notebooks/dispersion/stix_dispersion
